export const optimize = (objectiveFunction, options) => {
    const goldenRatio = (Math.sqrt(5) - 1) / 2;
    const [a, b] = options.bounds;
    const tolerance = options.tolerance || 1e-5;
    const maxIterations = options.maxIterations || 1000;
    let x1 = b - goldenRatio * (b - a);
    let x2 = a + goldenRatio * (b - a);
    let f1 = objectiveFunction(x1);
    let f2 = objectiveFunction(x2);
    for (let i = 0; i < maxIterations; i++) {
        if (Math.abs(b - a) < tolerance) {
            break;
        }
        if (f1 < f2) {
            const b = x2;
            x2 = x1;
            f2 = f1;
            x1 = b - goldenRatio * (b - a);
            f1 = objectiveFunction(x1);
        }
        else {
            const a = x1;
            x1 = x2;
            f1 = f2;
            x2 = a + goldenRatio * (b - a);
            f2 = objectiveFunction(x2);
        }
    }
    const x = (a + b) / 2;
    const fx = objectiveFunction(x);
    return { x, fx };
};
//# sourceMappingURL=feature_optimize.js.map